import type { ExtensionTheme } from './base';
/**
 * CSS Variables interface for customizing the assistant panel's appearance.
 * These variables can be overridden by users to customize the look and feel.
 *
 * @example
 * ```ts
 * createCompleteTheme({
 *   variables: {
 *     '--cm-ext-assistant-text': '#ffffff',
 *     '--cm-ext-assistant-bg-message': 'rgba(255, 255, 255, 0.1)',
 *   }
 * })
 * ```
 */
export interface AssistantThemeVariables {
    '--cm-ext-assistant-text': string;
    '--cm-ext-assistant-text-secondary': string;
    '--cm-ext-assistant-border': string;
    '--cm-ext-assistant-bg-input': string;
    '--cm-ext-assistant-bg-message': string;
    '--cm-ext-assistant-bg-selected': string;
    '--cm-ext-assistant-accent': string;
    '--cm-ext-assistant-bg-code': string;
    '--cm-ext-assistant-border-focus': string;
    '--cm-ext-assistant-font': string;
    '--cm-ext-assistant-font-mono': string;
    '--cm-ext-assistant-font-size': string;
    '--cm-ext-assistant-line-height': string;
    '--cm-ext-assistant-font-size-header': string;
    '--cm-ext-assistant-font-weight-header': string;
    '--cm-ext-assistant-font-size-message': string;
}
export declare const assistantThemeVariables: AssistantThemeVariables;
/**
 * Assistant theme configuration.
 *
 * Public CSS Classes for Styling:
 * - .cm-ext-assistant-container: Main container of the assistant panel
 * - .cm-ext-assistant-tab: Individual tab buttons
 * - .cm-ext-assistant-message: Message bubbles in the chat
 * - .cm-ext-assistant-code: Code block containers
 * - .cm-ext-assistant-input: Input area container
 *
 * Each of these classes can be styled using the CSS variables defined in AssistantThemeVariables.
 */
export declare const assistantTheme: ExtensionTheme;
